@@ -20,8 +20,8 @@
 
 /* Various symbol table handling functions, including symbol lookup */
 
-#include <stdlib.h>
-#include <string.h>
+/*#include <stdlib.h>*/
+#include "string.h"
 #ifdef IBCS_COMPATIBLE
 #include <ibcs/unistd.h>
 #else
