@@ -37,16 +37,17 @@ an ELF sharable library or a linux style of shared library. */
    a more than adequate job of explaining everything required to get this
    working. */
 
-#include <errno.h>
-#include <unistd.h>
-#include <stdlib.h>
-#include <string.h>
+#include <linux/types.h>
+#include <linux/errno.h>
+#include <linux/unistd.h>
+/*#include <stdlib.h>*/
+#include "string.h"
 #ifdef IBCS_COMPATIBLE
 #include <ibcs/unistd.h>
 #else
 #include <linux/unistd.h>
 #endif
-#include <fcntl.h>
+#include <linux/fcntl.h>
 #include <linux/elf.h>
 
 #include "hash.h"
