@@ -42,7 +42,7 @@ install -d -m 755 $PREFIX/usr/bin
 install -d -m 755 $PREFIX/usr/lib
 install -d -m 755 $PREFIX/usr/man/man1
 install -d -m 755 $PREFIX/usr/man/man8
-install -d -m 755 $PREFIX/usr/info
+#install -d -m 755 $PREFIX/usr/info
 if [ $devfiles = true ] ; then
     install -d -m 755 $PREFIX/usr/include
     install -d -m 755 $PREFIX/usr/man/man3
@@ -97,10 +97,11 @@ $PREFIX/sbin/ldconfig
 echo Installing manual and info pages
 install -m 644 man/ldd.1 $PREFIX/usr/man/man1
 install -m 644 man/ldconfig.8 man/ld.so.8 $PREFIX/usr/man/man8
-install -m 644 man/ld.so.info $PREFIX/usr/info
+#install -m 644 man/ld.so.info $PREFIX/usr/info
 if [ $devfiles = true ] ; then
     install -m 644 man/dlopen.3 $PREFIX/usr/man/man3
     ln -sf dlopen.3 $PREFIX/usr/man/man3/dlsym.3
+    ln -sf dlopen.3 $PREFIX/usr/man/man3/dladdr.3
     ln -sf dlopen.3 $PREFIX/usr/man/man3/dlerror.3
     ln -sf dlopen.3 $PREFIX/usr/man/man3/dlclose.3
 fi
