@@ -17,6 +17,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <stdarg.h>
 #include <string.h>
 #include <getopt.h>
 #include <unistd.h>
@@ -25,6 +26,62 @@
 #include <sys/wait.h>
 #include <linux/elf.h>
 #include "../config.h"
+#include "readelf.h"
+
+#ifdef __GNUC__
+void warn(char *fmt, ...) __attribute__ ((format (printf, 1, 2)));
+void error(char *fmt, ...) __attribute__ ((format (printf, 1, 2)));
+#endif
+
+char *prog = NULL;
+
+void warn(char *fmt, ...)
+{
+    va_list ap;
+
+    fflush(stdout);    /* don't mix output and error messages */
+    fprintf(stderr, "%s: warning: ", prog);
+
+    va_start(ap, fmt);
+    vfprintf(stderr, fmt, ap);
+    va_end(ap);
+
+    fprintf(stderr, "\n");
+
+    return;
+}
+
+void error(char *fmt, ...)
+{
+    va_list ap;
+
+    fflush(stdout);    /* don't mix output and error messages */
+    fprintf(stderr, "%s: ", prog);
+
+    va_start(ap, fmt);
+    vfprintf(stderr, fmt, ap);
+    va_end(ap);
+
+    fprintf(stderr, "\n");
+
+    exit(1);
+}
+
+void *xmalloc(size_t size)
+{
+    void *ptr;
+    if ((ptr = malloc(size)) == NULL)
+	error("out of memory");
+    return ptr;
+}
+
+char *xstrdup(char *str)
+{
+    char *ptr;
+    if ((ptr = strdup(str)) == NULL)
+	error("out of memory");
+    return ptr;
+}
 
 /* see if prog is a binary file */
 int is_bin(char *argv0, char *prog)
@@ -32,6 +89,8 @@ int is_bin(char *argv0, char *prog)
     int res = 0;
     FILE *file;
     struct exec exec;
+    char *cp;
+    int libtype;
 
     /* must be able to open it for reading */
     if ((file = fopen(prog, "rb")) == NULL)
@@ -74,7 +133,12 @@ int is_bin(char *argv0, char *prog)
 		    }
 		    break;
 		  case ET_DYN:
-		    res = 4;
+		    if ((cp = readsoname(prog, file, LIB_ANY, &libtype)) != NULL)
+		        free(cp);
+		    if (libtype == LIB_ELF_LIBC5)
+		        res = 5;
+		    else
+		        res = 4;
 		    break;
 		  default:
 		    res = 0;
@@ -103,6 +167,8 @@ int main(int argc, char **argv, char **envp)
     /* this must be volatile to work with -O, GCC bug? */
     volatile loadptr loader = (loadptr)LDSO_ADDR;
   
+    prog = argv[0];
+
     while ((i = getopt(argc, argv, "drvV")) != EOF)
 	switch (i)
 	{
@@ -191,10 +257,17 @@ int main(int argc, char **argv, char **envp)
 	      case 2: /* ELF program */
 		execl(argv[i], argv[i], NULL);
 		break;
-	      case 4: /* ELF library */
+	      case 4: /* ELF libc6 library */
 		/* try to use /lib/ld-linux.so.2 first */
+#if !defined(__mc68000__)
 		execl("/lib/ld-linux.so.2", "/lib/ld-linux.so.2", 
 		      "--list", argv[i], NULL);
+#else
+		execl("/lib/ld.so.1", "/lib/ld.so.1", 
+		      "--list", argv[i], NULL);
+#endif
+		/* fall through */
+	      case 5: /* ELF libc5 library */
 	        /* if that fials, add library to LD_PRELOAD and 
 		   then execute lddstub */
 		if (ld_preload && *ld_preload)
